@@ -143,6 +143,49 @@ def evalr_expr(
     return res
 
 
+def evalr_expr_with_visible(
+        expr: 'ExprSexpVector',
+        envir: typing.Union[
+            None,
+            'SexpEnvironment'] = None
+) -> 'ListSexpVector':
+    """Evaluate an R expression and return value and visibility flag.
+
+    :param expr: An R expression.
+    :param envir: An environment in which the expression will be evaluated.
+
+    :return: An R list with (value, visibility) where visibility is
+    an R boolean.
+    """
+    if envir is None:
+        envir = evaluation_context.get()
+    assert isinstance(envir, SexpEnvironment)
+
+    error_occured = _rinterface.ffi.new('int *', 0)
+    with memorymanagement.rmemory() as rmemory:
+        r_call_nested = rmemory.protect(
+            openrlib.rlib.Rf_lang2(
+                baseenv['eval'].__sexp__._cdata,
+                expr.__sexp__._cdata)
+        )
+        r_call = rmemory.protect(
+            openrlib.rlib.Rf_lang2(
+                baseenv['withVisible'].__sexp__._cdata,
+                r_call_nested)
+        )
+        r_res = rmemory.protect(
+                openrlib.rlib.R_tryEval(
+                    r_call,
+                    envir.__sexp__._cdata,  # call context.
+                    error_occured)
+        )
+        if error_occured[0]:
+            raise embedded.RRuntimeError(_rinterface._geterrmessage())
+        res = conversion._cdata_to_rinterface(r_res)
+        assert isinstance(res, ListSexpVector)
+    return res
+
+
 def evalr(
         source: str,
         maxlines: int = -1,
@@ -1002,7 +1045,21 @@ def initr_simple() -> typing.Optional[int]:
         return status
 
 
-def initr_checkenv() -> typing.Optional[int]:
+def initr_checkenv(
+        interactive: typing.Optional[bool] = None,
+        _want_setcallbacks: bool = True,
+        _c_stack_limit: typing.Optional[int] = None
+) -> typing.Optional[int]:
+    """Initialize the embedded R.
+
+    :param interactive: Should R run in interactive or non-interactive mode?
+    if `None` the value in `_DEFAULT_R_INTERACTIVE` will be used.
+    :param _want_setcallbacks: Should custom rpy2 callbacks for R frontends
+    be set?.
+    :param _c_stack_limit: Limit for the C Stack.
+    if `None` the value in `_DEFAULT_C_STACK_LIMIT` will be used.
+    """
+
     # Force the internal initialization flag if there is an environment
     # variable that indicates that R was already initialized in the current
     # process.
@@ -1012,7 +1069,9 @@ def initr_checkenv() -> typing.Optional[int]:
         if embedded.is_r_externally_initialized():
             embedded._setinitialized()
         else:
-            status = embedded._initr()
+            status = embedded._initr(interactive=interactive,
+                                     _want_setcallbacks=_want_setcallbacks,
+                                     _c_stack_limit=_c_stack_limit)
             embedded.set_python_process_info()
         _rinterface._register_external_symbols()
         _post_initr_setup()
